diff --git a/src/backend/commands/aggregatecmds.c b/src/backend/commands/aggregatecmds.c
index fde5a2a0e0..615ac5817c 100644
--- a/src/backend/commands/aggregatecmds.c
+++ b/src/backend/commands/aggregatecmds.c
@@ -12,11 +12,11 @@
  *	  src/backend/commands/aggregatecmds.c
  *
  * DESCRIPTION
- *	  The "DefineFoo" routines take the parse tree and pick out the
- *	  appropriate arguments/flags, passing the results to the
- *	  corresponding "FooDefine" routines (in src/catalog) that do
- *	  the actual catalog-munging.  These routines also verify permission
- *	  of the user to execute the command.
+ *	  The "DefineAggregate" routine take the parse tree and pick out the
+ *	  appropriate arguments/flags, passing the results to
+ *	  "AggregateCreate" routine (src src/backend/catalog) that do the actual
+ *	  catalog-munging.  These routines also verify permission of the user to
+ *	  execute the command.
  *
  *-------------------------------------------------------------------------
  */
diff --git a/src/backend/commands/define.c b/src/backend/commands/define.c
index 43f50066ea..ed67d3add0 100644
--- a/src/backend/commands/define.c
+++ b/src/backend/commands/define.c
@@ -11,23 +11,6 @@
  * IDENTIFICATION
  *	  src/backend/commands/define.c
  *
- * DESCRIPTION
- *	  The "DefineFoo" routines take the parse tree and pick out the
- *	  appropriate arguments/flags, passing the results to the
- *	  corresponding "FooDefine" routines (in src/catalog) that do
- *	  the actual catalog-munging.  These routines also verify permission
- *	  of the user to execute the command.
- *
- * NOTES
- *	  These things must be defined and committed in the following order:
- *		"create function":
- *				input/output, recv/send procedures
- *		"create type":
- *				type
- *		"create operator":
- *				operators
- *
- *
  *-------------------------------------------------------------------------
  */
 #include "postgres.h"
diff --git a/src/backend/commands/functioncmds.c b/src/backend/commands/functioncmds.c
index 6fc3863265..82dd659893 100644
--- a/src/backend/commands/functioncmds.c
+++ b/src/backend/commands/functioncmds.c
@@ -15,7 +15,7 @@
  * DESCRIPTION
  *	  These routines take the parse tree and pick out the
  *	  appropriate arguments/flags, and pass the results to the
- *	  corresponding "FooDefine" routines (in src/catalog) that do
+ *	  corresponding "FooCreate" routines (in src/backend/catalog) that do
  *	  the actual catalog-munging.  These routines also verify permission
  *	  of the user to execute the command.
  *
diff --git a/src/backend/commands/operatorcmds.c b/src/backend/commands/operatorcmds.c
index 5872a3e192..ec8b053ba4 100644
--- a/src/backend/commands/operatorcmds.c
+++ b/src/backend/commands/operatorcmds.c
@@ -14,7 +14,7 @@
  * DESCRIPTION
  *	  The "DefineFoo" routines take the parse tree and pick out the
  *	  appropriate arguments/flags, passing the results to the
- *	  corresponding "FooDefine" routines (in src/catalog) that do
+ *	  corresponding "FooCreate" routines (in src/backend/catalog) that do
  *	  the actual catalog-munging.  These routines also verify permission
  *	  of the user to execute the command.
  *
diff --git a/src/backend/commands/typecmds.c b/src/backend/commands/typecmds.c
index 4f20b5be06..a6bb0b70f5 100644
--- a/src/backend/commands/typecmds.c
+++ b/src/backend/commands/typecmds.c
@@ -13,7 +13,7 @@
  * DESCRIPTION
  *	  The "DefineFoo" routines take the parse tree and pick out the
  *	  appropriate arguments/flags, passing the results to the
- *	  corresponding "FooDefine" routines (in src/catalog) that do
+ *	  corresponding "FooCreate" routines (in src/backend/catalog) that do
  *	  the actual catalog-munging.  These routines also verify permission
  *	  of the user to execute the command.
  *
diff --git a/src/backend/tcop/utility.c b/src/backend/tcop/utility.c
index 33dea5a781..c2ed8214ef 100644
--- a/src/backend/tcop/utility.c
+++ b/src/backend/tcop/utility.c
@@ -122,7 +122,7 @@ CommandIsReadOnly(PlannedStmt *pstmt)
 /*
  * Determine the degree to which a utility command is read only.
  *
- * Note the definitions of the relevant flags in src/include/utility/tcop.h.
+ * Note the definitions of the relevant flags in src/include/tcop/utility.h.
  */
 static int
 ClassifyUtilityCommandAsReadOnly(Node *parsetree)
diff --git a/src/backend/utils/misc/guc_internal.h b/src/backend/utils/misc/guc_internal.h
index 9695dcd5b7..91acc1b320 100644
--- a/src/backend/utils/misc/guc_internal.h
+++ b/src/backend/utils/misc/guc_internal.h
@@ -6,7 +6,7 @@
  *
  * Copyright (c) 2000-2024, PostgreSQL Global Development Group
  *
- * src/include/utils/guc_internal.h
+ * src/backend/utils/misc/guc_internal.h
  *--------------------------------------------------------------------
  */
 #ifndef GUC_INTERNAL_H
diff --git a/src/fe_utils/astreamer_file.c b/src/fe_utils/astreamer_file.c
index 47568da2db..b20ef5019c 100644
--- a/src/fe_utils/astreamer_file.c
+++ b/src/fe_utils/astreamer_file.c
@@ -9,7 +9,7 @@
  * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
  *
  * IDENTIFICATION
- *		  src/bin/pg_basebackup/astreamer_file.c
+ *		  src/fe_utils/astreamer_file.c
  *-------------------------------------------------------------------------
  */
 
diff --git a/src/fe_utils/astreamer_gzip.c b/src/fe_utils/astreamer_gzip.c
index e0b755317c..8f966a34b5 100644
--- a/src/fe_utils/astreamer_gzip.c
+++ b/src/fe_utils/astreamer_gzip.c
@@ -20,7 +20,7 @@
  * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
  *
  * IDENTIFICATION
- *		  src/bin/pg_basebackup/astreamer_gzip.c
+ *		  src/fe_utils/astreamer_gzip.c
  *-------------------------------------------------------------------------
  */
 
diff --git a/src/fe_utils/astreamer_lz4.c b/src/fe_utils/astreamer_lz4.c
index a628088edf..98c83139ef 100644
--- a/src/fe_utils/astreamer_lz4.c
+++ b/src/fe_utils/astreamer_lz4.c
@@ -9,7 +9,7 @@
  * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
  *
  * IDENTIFICATION
- *		  src/bin/pg_basebackup/astreamer_lz4.c
+ *		  src/fe_utils/astreamer_lz4.c
  *-------------------------------------------------------------------------
  */
 
diff --git a/src/fe_utils/astreamer_tar.c b/src/fe_utils/astreamer_tar.c
index f5d3562d28..53a956a71d 100644
--- a/src/fe_utils/astreamer_tar.c
+++ b/src/fe_utils/astreamer_tar.c
@@ -15,7 +15,7 @@
  * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
  *
  * IDENTIFICATION
- *		  src/bin/pg_basebackup/astreamer_tar.c
+ *		  src/fe_utils/astreamer_tar.c
  *-------------------------------------------------------------------------
  */
 
diff --git a/src/fe_utils/astreamer_zstd.c b/src/fe_utils/astreamer_zstd.c
index 4b2d42b231..525ca64a2e 100644
--- a/src/fe_utils/astreamer_zstd.c
+++ b/src/fe_utils/astreamer_zstd.c
@@ -9,7 +9,7 @@
  * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
  *
  * IDENTIFICATION
- *		  src/bin/pg_basebackup/astreamer_zstd.c
+ *		  src/fe_utils/astreamer_zstd.c
  *-------------------------------------------------------------------------
  */
 
diff --git a/src/include/fe_utils/astreamer.h b/src/include/fe_utils/astreamer.h
index 570cfba304..7aa10b4f5e 100644
--- a/src/include/fe_utils/astreamer.h
+++ b/src/include/fe_utils/astreamer.h
@@ -24,7 +24,7 @@
  * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
  *
  * IDENTIFICATION
- *		  src/bin/pg_basebackup/astreamer.h
+ *		  src/include/fe_utils/astreamer.h
  *-------------------------------------------------------------------------
  */
 
